boreal.audio\_widgets package
=============================

Submodules
----------

boreal.audio\_widgets.audio module
----------------------------------

.. automodule:: boreal.audio_widgets.audio
   :members:
   :undoc-members:
   :show-inheritance:

boreal.audio\_widgets.audio\_processors module
----------------------------------------------

.. automodule:: boreal.audio_widgets.audio_processors
   :members:
   :undoc-members:
   :show-inheritance:

boreal.audio\_widgets.audio\_widgets module
-------------------------------------------

.. automodule:: boreal.audio_widgets.audio_widgets
   :members:
   :undoc-members:
   :show-inheritance:

boreal.audio\_widgets.main module
---------------------------------

.. automodule:: boreal.audio_widgets.main
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: boreal.audio_widgets
   :members:
   :undoc-members:
   :show-inheritance:
